@@ -96,8 +96,8 @@ and fonts registered.
 package ODF::lpOD_Helper;
 
 { no strict 'refs'; ${__PACKAGE__."::VER"."SION"} = 997.999; }
-our $VERSION = '6.008'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
-our $DATE = '2023-11-09'; # DATE from Dist::Zilla::Plugin::OurDate
+our $VERSION = '6.009'; # VERSION from Dist::Zilla::Plugin::OurPkgVersion
+our $DATE = '2023-11-16'; # DATE from Dist::Zilla::Plugin::OurDate
 
 use Carp;
 use Data::Dumper::Interp 6.004 qw/visnew
@@ -1503,7 +1503,7 @@ sub ODF::lpOD::Element::Hinsert_content {
       $span->set_attribute('style-name', $stylename);
       $span->ODF::lpOD::TextElement::set_text($vtext);
       if (%hyperlink_params) {
-        my $url = delete %hyperlink_params{url} // croak "No hyperlink 'url'";
+        my $url = delete $hyperlink_params{url} // croak "No hyperlink 'url'";
         # Example in ODF::lpOD::TextElement
         $span->set_hyperlink(filter => '.*', url => $url);
       }
